@@ -5,10 +5,28 @@ import matplotlib.pyplot as plt
 
 
 class objearth():
-    def __init__(self,DataArray):
-        self.DataArray = DataArray
+    def __init__(self):
+        pass
 
-    def plotshow(self,lst=True):
+    def clearcloud(self,Dataset0,Dataset1):
+        self.Dataset0 = Dataset0
+        self.Dataset1 = Dataset1
+        pixel0 = self.Dataset0.pixel_qa
+        mask1 = xarray.where(pixel0==352,1,0)    
+        mask2 = xarray.where(pixel0==480,1,0)
+        mask3 = xarray.where(pixel0==944,1,0)
+        sum = mask1+mask2+mask3
+        mask0 = xarray.where(sum.data>0,1,0)
+        blue        = xarray.where(mask0,self.Dataset1.blue,self.Dataset0.blue)
+        green       = xarray.where(mask0,self.Dataset1.green,self.Dataset0.green)
+        red         = xarray.where(mask0,self.Dataset1.red,self.Dataset0.red)
+        nir         = xarray.where(mask0,self.Dataset1.nir,self.Dataset0.nir)
+        pixel_qa    = xarray.where(mask0,self.Dataset1.pixel_qa,self.Dataset0.pixel_qa)
+        # Create DataArray
+        return xarray.merge([blue,green,red,nir,pixel_qa])
+
+    def plotshow(self,DataArray,lst=True):
+        self.DataArray = DataArray
         self.lst = lst
         if type(self.DataArray) == xarray.core.dataarray.DataArray:
             if self.lst==True:
